package com.sample;

import java.util.List;

import org.jbpm.runtime.manager.impl.task.SynchronizedTaskService;
import org.jbpm.services.task.impl.command.CommandBasedTaskService;
import org.jbpm.test.JbpmJUnitBaseTestCase;
import org.junit.Test;
import org.kie.api.runtime.KieSession;
import org.kie.api.runtime.manager.RuntimeEngine;
import org.kie.api.runtime.manager.RuntimeManager;
import org.kie.api.runtime.process.ProcessInstance;
import org.kie.api.task.TaskLifeCycleEventListener;
import org.kie.api.task.TaskService;
import org.kie.api.task.model.TaskSummary;
import org.kie.internal.task.api.EventService;

/**
 * This is a sample file to launch a process.
 */
public class ProcessTest extends JbpmJUnitBaseTestCase {

	@Test
	public void testProcess() {
		RuntimeManager manager = createRuntimeManager("rewards-basic-excluded-owners.bpmn2");
		RuntimeEngine engine = getRuntimeEngine(null);
		KieSession ksession = engine.getKieSession();
		TaskService taskService = engine.getTaskService();
		((EventService<TaskLifeCycleEventListener>)taskService).registerTaskEventListener(new CustomTaskEventListener());
		ProcessInstance processInstance = ksession.startProcess("com.sample.rewards-basic-excluded-owners");

		assertProcessInstanceActive(processInstance.getId(), ksession);
		
		// let john execute Task 1
		List<TaskSummary> list = taskService.getTasksAssignedAsPotentialOwner("john", "en-UK");
		TaskSummary task = list.get(0);
		System.out.println("John is executing task " + task.getName());
		taskService.start(task.getId(), "john");
		taskService.complete(task.getId(), "john", null);
		
		// Get excluded task for john
        list = ((SynchronizedTaskService)taskService).getTasksAssignedAsExcludedOwner("john", "en-UK");
        
        if (list.size() > 0) {
        	task = list.get(0);
        	System.out.println("John is excluded for " + task.getName());
        } else {
        	System.out.println("There is no excluded task for john");
        }
        
		// let mary execute Task 2
		list = taskService.getTasksAssignedAsPotentialOwner("john", "en-UK");
		task = list.get(0);
		System.out.println("John is executing task " + task.getName());
		taskService.start(task.getId(), "john");
		taskService.complete(task.getId(), "john", null);

		assertProcessInstanceCompleted(processInstance.getId(), ksession);
		
		manager.disposeRuntimeEngine(engine);
		manager.close();
	}
	
	public ProcessTest() {
		super(true, true);
	}

}